@@ -6,10 +6,11 @@
 */
 
 #include "ldapserver.h"
+using namespace Qt::Literals::StringLiterals;
 
-#include "ldap_debug.h"
+#include "ldap_core_debug.h"
 
-using namespace KLDAP;
+using namespace KLDAPCore;
 
 class Q_DECL_HIDDEN LdapServer::LdapServerPrivate
 {
@@ -294,7 +295,7 @@ void LdapServer::setUrl(const LdapUrl &url)
     d->mFilter = url.filter();
 
     d->mSecurity = None;
-    if (url.scheme() == QLatin1String("ldaps")) {
+    if (url.scheme() == "ldaps"_L1) {
         d->mSecurity = SSL;
     } else if (url.hasExtension(QStringLiteral("x-tls"))) {
         d->mSecurity = TLS;
@@ -415,7 +416,7 @@ int LdapServer::completionWeight() const
     return d->mCompletionWeight;
 }
 
-QDebug operator<<(QDebug d, const KLDAP::LdapServer &t)
+QDebug operator<<(QDebug d, const KLDAPCore::LdapServer &t)
 {
     d << "completionWeight " << t.completionWeight();
     d << "timeout " << t.timeout();
