@@ -7,9 +7,10 @@
 
 #include "ldapurl.h"
 
-#include "ldap_debug.h"
+#include "ldap_core_debug.h"
 
-using namespace KLDAP;
+using namespace KLDAPCore;
+using namespace Qt::Literals::StringLiterals;
 
 class Q_DECL_HIDDEN LdapUrl::LdapUrlPrivate
 {
@@ -125,7 +126,7 @@ LdapUrl::Extension LdapUrl::extension(const QString &key) const
         return *it;
     } else {
         Extension ext;
-        ext.value = QLatin1String("");
+        ext.value = ""_L1;
         ext.critical = false;
         return ext;
     }
@@ -192,8 +193,8 @@ void LdapUrl::updateQuery()
 
     // set the filter
     q += QLatin1Char('?');
-    if (d->m_filter != QLatin1String("(objectClass=*)") && !d->m_filter.isEmpty()) {
-        q += QLatin1String(toPercentEncoding(d->m_filter));
+    if (d->m_filter != "(objectClass=*)"_L1 && !d->m_filter.isEmpty()) {
+        q += QLatin1StringView(toPercentEncoding(d->m_filter));
     }
 
     // set the extensions
@@ -204,7 +205,7 @@ void LdapUrl::updateQuery()
         }
         q += it.key();
         if (!it.value().value.isEmpty()) {
-            q += QLatin1Char('=') + QLatin1String(toPercentEncoding(it.value().value));
+            q += QLatin1Char('=') + QLatin1StringView(toPercentEncoding(it.value().value));
         }
         q += QLatin1Char(',');
     }
@@ -242,9 +243,9 @@ void LdapUrl::parseQuery()
             d->m_attributes = (*it).split(QLatin1Char(','), Qt::SkipEmptyParts);
             break;
         case 1:
-            if ((*it) == QLatin1String("sub")) {
+            if ((*it) == "sub"_L1) {
                 d->m_scope = Sub;
-            } else if ((*it) == QLatin1String("one")) {
+            } else if ((*it) == "one"_L1) {
                 d->m_scope = One;
             }
             break;
@@ -269,7 +270,7 @@ void LdapUrl::parseQuery()
             name.remove(0, 1);
         }
         qCDebug(LDAP_LOG) << "LdapUrl extensions name=" << name << "value:" << value;
-        ext.value = value.replace(QLatin1String("%2"), QLatin1String(","));
+        ext.value = value.replace("%2"_L1, ","_L1);
         setExtension(name, ext);
     }
 }
